@@ -40,6 +40,10 @@ class Curve(ABC):
     def end_point(self):
         pass
 
+    @property
+    def end_point(self):
+        return self.end_point()
+
     @abstractmethod
     def line_representation(self) -> List:
         pass
@@ -340,7 +344,7 @@ class CatmullRom(Curve):
         Curve.__init__(self, id, control_points[0])
 
         if len(control_points) < 4:
-            raise ValueError(f"Invalid input for control points. Must have at least 4 values but list of lenght {len(control_points)} was provided: [{control_points}]")
+            raise ValueError(f"Invalid input for control points. Must have at least 4 values but list of length {len(control_points)} was provided: [{control_points}]")
         self.control_points = control_points
 
     def line_representation(self):
@@ -455,7 +459,8 @@ class CurveBuilder:
         self.current_points.append(point)
 
     def remove_point(self):
-        self.current_points.pop()
+        if any(self.current_points):
+            self.current_points.pop()
 
     def orientation(self, origin, destination) -> List[Orientation]:
         orientation = None
